@@ -21,3 +21,6 @@ class AbstractHandleExit(metaclass=ABCMeta):
     """Abstract to handle the program exit"""
 
     is_user_running: bool
+
+    def set_is_user_running(self, is_running: bool):
+        """ Set the user running status to True or False, and send signals if any"""
