@@ -26,9 +26,7 @@ class NelderMeadStoppingCriteria(StoppingCriteria):
         """
         # Call to the super class constructor
         super().__init__(stopping_criteria)
-        # frtol and xatol
         self.xatol = stopping_criteria.setdefault("xatol", 1e-14)
-        self.frtol = stopping_criteria.setdefault("frtol", 1e-13)
         self.fatol = stopping_criteria.setdefault("fatol", 1e-100)
         # self.is_converged = False
 
